Dynamic protein coronas revealed as a modulator of silver nanoparticle sulphidation in vitro | Nature Communications
Author: Miclăuş, Teodora
Description: Proteins adsorbing at nanoparticles have been proposed as critical toxicity mediators and are included in ongoing efforts to develop predictive tools for safety assessment. Strongly attached proteins can be isolated, identified and correlated to changes in nanoparticle state, cellular association or toxicity. Weakly attached, rapidly exchanging proteins are also present at nanoparticles, but are difficult to isolate and have hardly been examined. Here we study rapidly exchanging proteins and show for the first time that they have a strong modulatory effect on the biotransformation of silver nanoparticles. Released silver ions, known for their role in particle toxicity, are found to be trapped as silver sulphide nanocrystals within the protein corona at silver nanoparticles in serum-containing cell culture media. The strongly attached corona acts as a site for sulphidation, while the weakly attached proteins reduce nanocrystal formation in a serum-concentration-dependent manner. Sulphid [cell cut: 1350 characters, first 1000 kept]
Keywords: Biomaterials – proteins
Date: 2016-06-09

Skip to main content

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Advertisement

Dynamic protein coronas revealed as a modulator of silver nanoparticle sulphidation in vitro
Download PDF

- Open Access
- Published: 09 June 2016

# Dynamic protein coronas revealed as a modulator of silver nanoparticle sulphidation in vitro

- Teodora Miclăuş1,
- Christiane Beer2,
- Jacques Chevallier3,
- Carsten Scavenius4,
- Vladimir E. Bochenkov1,5,
- Jan J. Enghild4 &
- Duncan S. Sutherland
  ORCID: orcid.org/0000-0002-5045-99151

Nature Communications volume 7, Article number: 11770 (2016) Cite this article

- 8471 Accesses

- 93 Citations

- 84 Altmetric

- Metrics details

### Subjects

- Biomaterials – proteins
- Inorganic chemistry
- Nanoparticles

## Abstract

Proteins adsorbing at nanoparticles have been proposed as critical toxicity mediators and are included in ongoing efforts to develop predictive tools for safety assessment. Strongly attached proteins can be isolated, identified and correlated to changes in nanoparticle state, cellular association or toxicity. Weakly attached, rapidly exchanging proteins are also present at nanoparticles, but are difficult to isolate and have hardly been examined. Here we study rapidly exchanging proteins and show for the first time that they have a strong modulatory effect on the biotransformation of silver nanoparticles. Released silver ions, known for their role in particle toxicity, are found to be trapped as silver sulphide nanocrystals within the protein corona at silver nanoparticles in serum-containing cell culture media. The strongly attached corona acts as a site for sulphidation, while the weakly attached proteins reduce nanocrystal formation in a serum-concentration-dependent manner. Sulphidation results in decreased toxicity of Ag NPs.

Download PDF

## Introduction

The biological effects of engineered nanomaterials as drug delivery vehicles or as unintentionally released nanoparticles (NPs) are of strong current interest. Biomolecules—mainly proteins—adsorbing at NPs modify their surface properties and are proposed as important modulators of particle–cell interactions1,2,3,4,5,6,7,8. A pragmatic distinction has been made between the relatively easily studied, strongly attached proteins as long-lived, hard coronas and the weakly attached, rapidly exchanging proteins as soft coronas9,10,11,12,13. The former are under focus with residence at the particles on timescales relevant for cellular binding and uptake4,6,14, whereas the role of the latter in modulating NP behaviour has yet to be established. Specific and different profiles of molecules concentrated within the hard corona at particles in biological media have been observed for different surface coatings15, charges16,17, sizes15,18 and shapes19. The concept of a biological identity imprinted within the protein corona and which determines NP–cellular interactions1,2,3,4,5,6 has been proposed20. Although the long-lived layer has been linked to particle aggregation19 and cell association6,14,21, the correlation of protein composition to cellular uptake/toxicity is still relatively weak4,22,23. The involvement of soft corona in physical and/or chemical transformations of particle with potential implications for toxicity is so far unstudied, despite it forming a dense second layer around the strongly attached biomolecules24.

In addition to protein corona formation, ion release is central to the toxicity of silver NPs and is an important parameter studied in vitro25,26,27 and in vivo28. Oxidation contributes to ion release through the formation of Ag2O on the particles29,30, which is then dissolved in aqueous media31,32,33. Oxidative dissolution is an important step in Ag2S formation from/at Ag NPs34. Silver NP sulphidation has been receiving increasing attention, as the resulting sulphide is insoluble in water, decreasing the availability of Ag+ and impacting antibacterial35 and toxicological36,37,38 effects. After identification of silver sulphide in sewage sludge39, interest in studying Ag2S was focused on wastewater plants40,41 and aquatic environments42. Although most toxicity experiments are conducted in vitro, much less is known about such transformations of Ag NPs under these conditions. Thiols (for example, cysteine) have been proven to bind Ag+ in biological environments43,44. Tracking the oxidation state of intracellular silver showed an evolution from Ag0 to oxygen-bound and sulphur-bound Ag ions45,46. Formation of Ag2S in alveolar cells was proposed to explain decreased toxicity of silver nanowires47 and their sulphidation in protein-free culture medium was recently studied48. A further step involves exploring chemical changes that occur in full culture media, in the presence of protein coronas, before cellular uptake.

Here we demonstrate one clear role for the soft corona in modulating silver NP sulphidation in vitro, and highlight the interplay between strongly and weakly attached proteins for the chemical transformation of Ag NPs. We also suggest some potential implications for toxicity, without, however, establishing a clear direct connection between the soft corona and observed toxicological effects. We show for the first time a functional effect of rapidly exchanging proteins, which decreased the amount of nano-Ag2S formed at polyvinylpyrrolidone (PVP)-coated Ag NPs incubated in serum-supplemented cell culture media. We propose and study a mechanism for soft corona protein-assisted Ag+ transport explaining reduced sulphide formation. Striking differences when going from in vitro to in vivo relevant protein concentrations are observed and discussed. As it is known that sulphidation decreases silver toxicity36,37,38,47,49,50,51, it is not surprising that under conditions where Ag NPs were partially or completely transformed into Ag2S in cell culture media, much less toxicity to J774 macrophages and different cytokine secretion profiles are seen compared with silver NPs.

## Results

### Protein coronas modulate nano-Ag2S formation at Ag NPs

Upon incubation of PVP-coated, cubic or quasi-spherical Ag NPs in RPMI-1640 cell culture medium supplemented with fetal bovine serum (FBS), new NPs were observed to form close to the surface of the silver. Details regarding incubation are available in the Methods section, Particle incubation in cell culture media subsection. Figure 1a shows a typical transmission electron microscopy (TEM) image of nanocubes after 7 days in 1% serum, with the NPs forming a dispersed layer around the silver core (highlighted by arrows). X-rays elemental mapping (Fig. 1b) and energy-dispersive X-ray spectroscopy (EDS, Fig. 1c) revealed the presence of sulphur. Co-localization of Ag and S matches the small NPs in the proximity of the silver surface (Fig. 1b). The diffraction line at 2.80 (Fig. 1d) corresponds to monoclinic Ag2S (ref. 52).

Figure 1: Silver sulphide forms close to the surface of Ag NPs.

TEM image with arrows highlighting nano-Ag2S (a, scale bar 50 nm), X-rays elemental mapping of Ag (red), S (blue, with white rings marking the approximate contour of the Ag NPs) and overlaid Ag and S (b), EDS spectrum—with arrows pointing at the peaks corresponding to each element—(c) and diffraction pattern—arrow pointing at the diffraction line corresponding to monoclinic Ag2S—(d) of silver nanocubes after 7 days incubation in RPMI-1640 supplemented with 1% FBS and formation of Ag2S at the surface of the Ag NPs.

Full size image

When in contact with biological media, NPs get covered with biomolecules1,2,3,4. Hard and soft protein coronas around silver nanocubes have previously been quantified and it has been shown that the polymer coating is replaced during the first hour in 1% serum24. We observe no sulphide within 1 h, before PVP replacement (Supplementary Fig. 1). The later appearance of Ag2S close to the silver surface suggests its formation is related to the layers of adsorbed biomolecules. We hypothesize a mechanism where protein coronas and ion release govern the formation of Ag2S at silver NPs (Fig. 2a). We propose that released Ag+ can get trapped in the long-lived protein corona where, if enough reduced sulphur and Ag+ are available, Ag2S may form. In contrast, the rapidly exchanging soft corona proteins prevent sulphide formation by transporting Ag+ away from the particle, thus decreasing local ion concentration. To test this hypothesis, one must account for both hard and soft corona proteins, as well as bulk biomolecules.

Figure 2: Protein coronas modulate sulphide formation.

Proposed mechanism of protein corona-modulated nano-Ag2S formation at Ag NPs, with hard corona proteins trapping Ag+ released from the nanoparticle surface and soft corona proteins transporting said ions away from the sulphide-formation centres in the long-lived corona (a); TEM images of silver nanocubes after 24 h in RPMI-1640 cell culture medium supplemented with 1% FBS (b), followed by 6 days incubation in RPMI-1640 with 0% FBS (inset cartoon showing only hard corona around Ag NPs) (c), 1% FBS (d) or 10% FBS (e; common inset cartoon showing hard and soft coronas, as well as free bulk proteins around Ag NPs); TEM images of silver nanocubes after 7 days incubation in RPMI-1640 with 0.4 mg ml−1 BSA (f) or 4 mg ml−1 BSA (g) (common inset cartoon showing hard corona and free bulk proteins around Ag NPs); Ultraviolet–visible spectra of cubic (h) and quasi-spherical (i) Ag NPs after 24 h incubation in RPMI-1640 cell culture medium supplemented with 1, 10 or 50% FBS; TEM images of silver nanocubes after 24 h in RPMI-1640 supplemented with 1% FBS (j), 10% FBS (k) and 50% FBS (l). Scale bars are 100 nm (b, j–l) or 50 nm (c–g).

Full size image

Silver nanocubes (Supplementary Fig. 2) were incubated in RPMI-1640 with 1% FBS for 24 h (Fig. 2b) to provide a stable hard corona (Supplementary Discussion). The particles were washed, removing unbound and loosely bound proteins while retaining the hard corona (Fig. 2c, cartoon), and re-suspended in RPMI-1640 without serum for 6 days. Similarly, particles were incubated for 7 days in 1 or 10% FBS to ensure the presence of hard and soft coronas, and bulk proteins (Fig. 2d,e cartoon). The same behaviour was seen for quasi-spherical NPs (Supplementary Fig. 3). Ag2S is observed under all incubation conditions where serum was present for at least the 24 h needed to fully form the hard corona24. Figure 2c–e shows typical TEM images of the different conditions–6 days at 0, 1 and 10% FBS after 24 h in serum-containing media. EDS confirmed the presence of sulphur (Supplementary Fig. 4). Although the total incubation time is the same (7 days) for all samples, the differences in Ag2S amounts are striking, with significantly more sulphide observed at the particle surfaces when soft corona and free bulk proteins are absent after the first day. Incubating Ag NPs in serum-containing media for the initial 24 h establishes a long-lived corona, stable after the transition to 0% FBS. It has previously been shown that the hard corona is similar after 24 h in 1 and 10% FBS for different silver nanocubes24, and in the present study, we observed the same protein profiles for NPs of various sizes (Supplementary Fig. 5). Here there is a similar long-lived layer on all Ag NPs, as confirmed by mass spectrometry (Supplementary Tables 1–3); what varies (0, 1 and 10% FBS) are the soft corona and the bulk protein concentrations. Nano-Ag2S formation at Ag NPs decreased with soft corona presence and the increase in free proteins, with significantly more sulphide at 0% than 1% and 10% FBS. The variation does not appear linear: differences between 1 and 10% FBS are not as striking as between 0 and 1%. Furthermore, although in the presence of serum the particles are dispersed even after 7 days (Supplementary Fig. 6), at 0% FBS the nano-Ag2S forms bridges between Ag NPs, which result in particle agglomeration (Fig. 2c).

Both soft corona and bulk proteins could bind Ag+; distinguishing between the two categories requires absence of one of them. To test the role of soft coronas, bovine serum albumin (BSA), at concentrations equivalent to 1, 10 or 50% FBS, was used to form a hard corona around silver nanocubes (Supplementary Fig. 7). When only BSA is present in the system, the protein–protein interactions needed to form soft coronas do not occur (Supplementary Fig. 8 and Supplementary Methods); incubation in albumin provides only hard coronas and bulk proteins (Fig. 2f,g, cartoon). Figure 2f,g shows slightly more nano-Ag2S formation when BSA concentration is increased from equivalent of 1% FBS to 10% FBS; the opposite phenomenon is observed for serum (Fig. 2d,e). Full sets of TEM images are available (Supplementary Figs 9 and 10); similar results were obtained when using lysozyme instead of BSA (Supplementary Figs 11 and 12). The observed increase in Ag2S content at higher albumin/lysozyme concentrations may be due to a thicker, faster-formed hard corona, allowing for trapping and sulphidation of more Ag+. Although sulphide appears for incubation in both FBS and BSA/lysozyme, increasing serum concentration—unlike increasing albumin/lysozyme concentration—decreases Ag2S formation. This is attributed to the lack of a soft corona when a single type of protein exists in the system11—as shown in Supplementary Fig. 8 and Supplementary Methods—as hard coronas and free bulk proteins are present in both cases.

To further study the soft corona influence, experiments were performed at serum concentrations from 1 to 50%, over 24 h. Ultraviolet–visible spectra were collected and plasmon peak shifts were observed. Owing to localized surface plasmon resonances, variations in peak position indicate refractive index changes around particles. Red shifts of 2–4 nm upon binding of proteins to Ag NPs have been seen previously24. Here, we observe changes of up to 45 nm indicating the presence of a material with high refractive index—like Ag2S—close to the Ag NPs. Comparison to TEM images (Fig. 2j,l and Supplementary Figs 13 and 14) shows the more sulphide present at the surface, the larger the red-shift in the plasmon peaks is. Increased protein concentration and, therefore, soft corona protein content24, results in a visible decrease of nano-Ag2S formation not just at prolonged incubation, but also after 24 h. Analysis of multiple TEM images revealed almost no sulphide at the NP surface in 50% serum. Furthermore, TEM and ultraviolet–visible data indicate a lower sulphide content after 24 h in 10% compared with 1% FBS. Figure 2h,i shows spectra for cubic and quasi-spherical Ag NPs after 24 h in 1, 10 or 50% serum. Decreasing FBS concentration and, implicitly, the amount of soft corona24, results in the formation of more Ag2S at Ag NPs, as suggested by the plasmon peak shifted towards higher wavelengths when going from 50% to 10% and 1% serum. NP dissolution (Supplementary Fig. 15) results in reshaping and resizing on a similar timescale for these nanocubes, with concomitant changes of the optical spectra. This leads to the decreased intensity of the signal around 350 nm, where a more prominent peak is characteristic of larger silver nanocubes, with sharper edges53. Reduction in particle diameter, coupled with shape changes from cubes to sphere-like, also explains the blue-shift around 435 nm (Fig. 2h) after incubation in 50% serum. No reshaping is observed for the quasi-spherical NPs, while slight diameter decrease may occur.

It has been shown that shifts in plasmon peak position, coupled with finite-difference time-domain simulations of plasmonic behaviour may be used to quantify refractive index changes caused by protein adsorption at Ag NPs24. Via a similar approach (Supplementary Figs 16 and 17, Supplementary Table 4 and Supplementary Methods) we estimate that, at the Ag NP concentration used here (10 μg ml−1), 15–40% of the silver is transformed into sulphide.

### Ion release from Ag NPs is necessary for nano-Ag2S formation

Sulphidation of silver NPs involves the presence of ionic silver therefore variations in Ag+ content may influence the formation of Ag2S. To test this parameter, AgNO3—with Ag+ representing 10% by weight of the particulate silver—was added to the NP suspension at the beginning of 1 or 7 days incubation in RPMI-1640 with 1% FBS (Supplementary Figs 18–21 for 10% serum). ultraviolet–visible spectra of quasi-spherical particles with or without extra ions were collected (Fig. 3a); a less pronounced red-shift was seen when free Ag+ were added, especially at short incubation, suggesting a slower NP dissolution in the presence of extra ions.

Figure 3: Silver nanoparticle dissolution is involved in nano-Ag2S formation.

Ultraviolet–visible full spectra of quasi-spherical Ag NPs (a) and quadrupole peak detail of nanocubes (b) incubated (1 day: blue or 7 days: pink) in RPMI-1640 cell culture medium supplemented with 1% FBS, with or without added extra 10% (by mass) Ag+ ions from AgNO3; EDS spectra of the supernatant obtained after centrifugation of Ag NPs incubated for 7 days in RPMI-1640 with 1% FBS, before (c) and after (d) spiking with 5 nm PVP-coated Ag NPs, with dotted red line highlighting the presence of a silver signal only in the spiked sample.

Full size image

Nanocubes have several characteristic plasmon peaks, of which a quadrupole (≈350 nm) and a dipole (≈435 nm; Supplementary Fig. 18). The quadrupole indicates the degree to which a NP is cubic, as well as its size53, and, as such, it is used to track the synthesis of silver nanocubes54 (Supplementary Fig. 22). Dissolution reduces particle size and blunts cube edges, resulting in flattening of the quadrupole peak (Fig. 3b). After 7 days in 1% FBS, the signal disappears almost completely.. At 24 h, both samples exhibit a pronounced quadrupole peak, with a visibly sharper signal when 10% free Ag+ were added at the beginning of the incubation. The results suggest Ag NPs in samples with added ions undergo slower and, perhaps, less dissolution, observable in resizing and reshaping of the particles. This behaviour could be explained by the existence of a plateau ion concentration in the bulk, as previously observed32,45. Adding free ions may decreases the amount of Ag+ required from NP dissolution for achieving this equilibrium concentration, but further investigations would be necessary to elucidate the mechanism.

Inspection of multiple TEM images suggests there is no difference in the amount of Ag2S at silver NPs with or without added 10% Ag+ at 7 days, but some decrease in sulphide incidence occurs at 24 h (Supplementary Fig. 19). This indicates the formation of nano-Ag2S requires the release of Ag+ from NPs and not just the existence of free ions in the bulk. The observation is strengthened by control experiments with silica particles in RPMI-1640 with FBS and free silver ions; no nano-Ag2S was detected after 7 days (Supplementary Fig. 23).

Atomic absorption spectroscopy (Supplementary Fig. 15) confirmed the presence of silver in the bulk, strengthening the soft corona ion transport mechanism; it did not, however, indicate the chemical form of the silver. Although the timescale of soft corona exchange is on the order of seconds and minutes and nano-Ag2S formation occurs over hours, we verified that at prolonged incubation the rapidly exchanging proteins do not transport Ag2S nano-crystals away from the Ag NP surface. We measured EDS spectra and mapped supernatants collected after 7 days incubation in 1% FBS, before and after spiking in PVP-coated Ag NPs (Fig. 3c,d and Supplementary Fig. 24) of similar size (5 nm) and amount to that of nano-Ag2S. If Ag2S nanocrystals were transported to the bulk, a peak would appear in the EDS spectrum around 3 keV. Absence of this signal in the un-spiked supernatant indicates nano-Ag2S is not transported by the soft corona.

### Sulphur sources and Ag/S ratio influence nano-Ag2S formation

Sulphur-containing gases can contribute to the formation of Ag2S at Ag NPs exposed to air, but this is a lengthy and slow process, extended over 24 weeks55. In the liquid phase, RPMI-1640 provides several sulphur sources (Supplementary Tables 5 and 6), with L-cysteine and L-methionine accounting for most of the reduced S; furthermore, many serum proteins contain cysteine residues. To pin-point the sulphur responsible for Ag2S formation in our case, we incubated Ag NPs in phosphate-buffered saline (PBS) supplemented with either 1% FBS or L-cysteine and L-methionine at the same concentrations as in RPMI-1640. After 7 days, no sulphide was seen in PBS or in buffer with serum (Fig. 4a,b), but nano-Ag2S was present in the amino-acid-supplemented buffer (Fig. 4c and Supplementary Fig. 25). EDS spectra (Fig. 4d) confirmed the observations from TEM images. These experiments show reduced sulphur from small molecules and not from proteins is the one forming Ag2S.

Figure 4: Sulphur sources and the Ag:S ratio influence Ag2S formation.

TEM images of Ag NPs after 7 days incubation in PBS (a), PBS supplemented with 1% FBS (b) and PBS supplemented with L-cysteine and L-methionine at the same concentrations of amino acids as those found in RPMI-1640 (c) and corresponding EDS spectra (d); TEM images and corresponding EDS spectra (insets) of Ag NPs after 7 days incubation in RPMI-1640 supplemented with 1% FBS, with initial silver concentrations of 2 μg ml−1 (e), 10 μg ml−1 (f) and 100 μg ml−1 (g), with elemental mapping images provided in Supplementary Fig. 26. Scale bars are 100 nm (a–c) or 50 nm (e–g).

Full size image

We further tested the effect of Ag/S ratios by varying the amount of nanocube stock suspension added to a given volume of serum-supplemented RPMI-1640. After 7 days, increasing the initial silver concentration from 2 to 10 and then to 100 μg ml−1 (Fig. 4e–g and Supplementary Fig. 26) drastically decreases Ag2S formation by limiting the L-cysteine and L-methionine available per Ag+. In vivo cysteine concentration is more than double that in RPMI, making more S available for Ag2S formation56,57. At the lowest Ag/S ratio, the particles are almost entirely transformed into Ag2S, forming ‘pockets’ of sulphide that conserve the shape of the initial particle, with the metal core still visible in some cases (Fig. 4e). These observations suggest sulphidation is confined to the protein hard corona, in agreement with EDS showing the absence of nano-Ag2S from the suspension supernatant (Fig. 3c,d).

### Protein corona-mediated sulphidation impacts cell toxicity

Previous research has already shown that trapping Ag+ in the form of insoluble Ag2S decreases the toxicity of silver50,51 and Ag NPs35,49, mostly in the case of aquatic environments36,37,58 and in soil38, which are settings with low protein contents, but higher concentrations of other components that are not prevalent under in vitro cell study conditions. Although the effects under in vitro parameters have not been studied to the same extent, some information is also available on the decreased toxicity of sulphidated Ag NPs to cultured cells47. Our results confirm such already published findings and extend the observations to a cell line where the consequences of sulphidation have not previously been investigated. We indirectly tested the effects of corona-mediated sulphidation on the toxicity of Ag NPs to J774 macrophages by exposing cells to partially and completely sulphidated NPs (obtained by pre-incubation in 10 and 1% FBS respectively, Fig. 5a,b) to mimic in vitro conditions, as well as NPs with no sulphide, to mimic in vivo settings (Supplementary Fig. 27). Detailed experimental procedures are available in the Methods section and in Supplementary Methods. Ag NPs disrupted mitochondrial activity, as measured using a 3-(4,5-dimethylthiazol-2-yl)-2,5-diphenyltetrazolium bromide (MTT) assay, and caused cell death at concentrations above 25 μg ml−1, whereas partially and completely transformed particles showed no effect at concentrations as high as 100 μg ml−1 (Fig. 5c). Silver ions were lethal to the cells even at the lowest concentration (2 μg ml−1), but pristine, partially and completely sulphidated Ag NPs were suitable for analysis of potential effects at sub-lethal doses. Of all the molecules measured in the cell supernatants, responses above the detection limit were seen for interleukin-1beta, interleukin-6, interleukin-18, tumour necrosis factor alpha (TNFα) and macrophage inflammatory protein 2 (MIP-2; Supplementary Fig. 28 and Fig. 5). Granulocyte–macrophage colony-stimulating factor was also measured at the highest particle doses in the Ag NPs samples, but for most systems, granulocyte–macrophage colony-stimulating factor values were below the detection limit and, therefore, they are not included here. The most pronounced impact is observed on TNFα and MIP-2. TNFα is a cytokine released by macrophages at early inflammatory stages together with interleukin 6 (ref. 59), which we also observed (Supplementary Fig. 28). A threefold increase in its production is caused by pristine and partially sulphidated Ag NPs, but not by completely transformed ones (Fig. 5d). This result indicates upregulation of TNFα production by Ag requires the presence of nano-particulate or ionic silver, as previously seen60,61. A similar trend (Fig. 5e) was observed for MIP-2, a cytokine involved in cell recruitment to the site of infection following the initiation of the inflammatory response62. Together, these results confirm that sulphidation, which we show is mediated by the dynamic protein coronas and is more likely to occur at the serum concentrations used in vitro than in vivo, decreases the toxicity of silver NPs both at lethal and sub-lethal doses. However, although we show, for the first time, a link between both soft and hard protein coronas and Ag NPs sulphidation and confirm previous findings connecting sulphidation to decreased toxicity, we cannot, at this time, provide a direct link between the soft corona and the diminished toxicological effects of sulphidated Ag NPs. Furthermore, technical limitations in conducting in vitro studies at different FBS concentrations do not allow us to account for the Ag+ transported by soft corona proteins in the bulk of the pre-incubation system. As silver ions are known for their toxicity and our experimental setting does not permit investigation of their interaction with cells when bound to rapidly exchanging proteins, we cannot make a general claim about the overall toxicological impact that the soft corona-mediated biotransformation of Ag NPs has under various in vitro or in vivo scenarios.

Figure 5: Corona-mediated sulphidation of Ag NPs impacts particle toxicity.

TEM images of partially sulphidated Ag NPs after pre-incubation in RPMI-1640 with 10% FBS (a) and completely sulphidated Ag NPs after pre-incubation in RPMI-1640 with 1% FBS (b); scale bars are 50 nm; Viability of J774 murine macrophages (as measured with MTT assays) after 24 h exposure to various concentrations (2, 5, 10, 15, 25, 50 and 100 μg ml−1) of Ag+ ions (black diamonds), pristine Ag NPs (red triangles), partially sulphidated Ag NPs (blue squares) and completely sulphidated Ag NPs (orange circles); error bars are provided as standard deviation; statistically significant differences (two-tailed t-test, with all data sets showing normal distribution and similar variance values) as compared with the control are marked with **P<0.005 or ***P<0.0005 (n=6), with all the P values available in Supplementary Table 7 (c); release profiles of TNFα (d) and MIP-2 (e) after 24 h exposure of J774 macrophages to various concentrations (2, 5, 10, 15, 25, 50 and 100 μg ml−1) of pristine (red), partially sulphidated (blue) and completely sulphidated (orange) Ag NPs; the missing concentrations of TNFα and MIP-2 after exposure to pristine Ag NPs are above the measuring limit (see calibration curves in Supplementary Fig. 29).

Full size image

## Discussion

We have shown for the first time a situation where the weakly attached protein layer forming the soft corona has a visible and measurable effect on the transformation of Ag NPs in a complex biological environment. We demonstrated the presence of crystalline nano-Ag2S at the surface of silver NPs upon incubation in cell culture medium. Reduced sulphur, an organic layer at the Ag NPs and release of ions from the metal core are necessary for sulphide formation. Protein concentration greatly impacted the amount of nano-Ag2S observed at the particles through a soft corona protein-assisted mechanism of Ag+ removal. In the absence of a rapidly exchanging corona, the decrease in sulphide formation upon increased bulk protein concentration was no longer observed, in agreement with the proposed mechanism. Greater free silver ion concentrations introduced in the media did not increase sulphide formation. We have studied well-defined Ag nanocubes and quasi-spherical particles formed via PVP stabilization. Although we expect the proposed mechanism to apply to Ag NPs having other sizes, shapes and coatings, the particulars of the experimental situation—such as incubation time, media, Ag2S formation rate and crystal size, protein concentration—are likely to influence the specific outcomes.

The low water solubility of Ag2S decreases Ag+ ions bioavailability and, although this phenomenon has been studied extensively in ecotoxicology settings32,37,39,40,41,42, little is known about the effect of NP sulphidation in cell culture media48. Ions are an important component in silver toxicity to cells; transformations impacting their availability should be taken into account when analysing the stability of Ag NPs in protein-containing media relevant for in vitro experiments and interpreting subsequent toxicity studies. We show that even partial sulphidation of Ag NPs prevents cell death, whereas complete sulphidation also prevents the increased pro-inflammatory cytokines production seen with pristine particles. The observed decrease in Ag2S formation at increased protein contents may raise a question regarding using in vitro results to predict in vivo scenarios, as the bulk biomolecule concentration in the latter settings is much higher than in the former. However, for this to become an issue, a direct link between the dynamic protein coronas and the toxic effects of Ag NPs should first be established in future research. Further studies into the bioavailability and effects of soft corona-bound Ag+ from particle dissolution in protein-containing media are also necessary to obtain a clear and full picture of how biomolecules-modulated biotransformations may change NPs’ toxicity effects in vitro and in vivo.

## Methods

### Particle synthesis and characterization

Silver NPs, both cubic and quasi-spherical, were prepared using the polyol method63, where particle shape is controlled by the ratio between the capping agent (PVP) and the silver precursor64. Briefly, a specific amount of silver trifluoroacetate dissolved in anhydrous ethylene glycol is reduced by ethylene glycol at high temperature (145–155 °C) in the presence of PVP (Mw≈55,000 Da). The ratio of PVP to CF3COOAg dictates the outcome regarding particle shape. For the cube synthesis, trace amounts of HCl and NaSH·xH2O are added to the reaction mixture, as described elsewhere63. The particles were purified by repeated washing with acetone, ethanol and MilliQ water24. The synthesis was tracked by collecting ultraviolet–visible spectra (Shimadzu UV-visible-NIR spectrophotometer, UV-3600) of the reaction mixture (a few drops in MilliQ water) at various times (Supplementary Fig. 22). The resulting silver particles were quantified using flame atomic absorption spectroscopy (F-AAS, PerkinElmer Analyst 300 atomic absorption spectrometer mounted with a silver lumina hollow cathode lamp), after digestion in 65% HNO3. NP size was obtained using the SPIP scanning probe image software (Image Metrology) to analyse TEM images of at least 500 particles.

### Particle incubation in cell culture media

RPMI-1640 (Invitrogen) is a medium widely used for cell cultures, including for the J774 murine macrophages employed here. We incubated Ag NPs (cubic or quasi-spherical) in RPMI-1640 with or without added supplements of heat-inactivated FBS (HyClone; 1–50% by volume), for 1 or 7 days. As we are studying a model system from the perspective of a mechanism of chemical transformation, our choice of serum concentrations and incubation times is only partially based on real toxicology settings. As such, 10% FBS is used as the typical serum supplement for in vitro toxicity studies65,66,67, with 24 h being the go-to time for acute toxicity experiments26,45,65,66,67,68,69. However, in vitro Ag NPs exposure studies have been performed at lower serum concentrations45,68,69, down to 1% (ref. 25), which is the concentration selected in our work. Furthermore, the 1% provides a better model system to study and understand mechanisms, as the low protein concentration makes the protein exchange-dependant process at the NP surface take longer, with fewer biomolecules available to participate. Although FBS contents higher than 10% are not common for in vitro studies, they are closer to an in vivo situation, so 50% serum was selected to better investigate the behaviour of Ag NPs in a realistic setting. However, we perform a mechanistic study on model systems, therefore the incubation times were chosen to have a fully formed hard corona on Ag NPs24 (24 h) and to observe an extensive chemical transformation of the NPs (7 days), even though the onset of the sulphidation occurs, as we show, much earlier and clear changes are visible at 24 h. To study the influence of free ions on nano-Ag2S formation, AgNO3 (Sigma-Aldrich) aqueous solutions (10% Ag+ by weight of the total Ag NP mass) were added to the media at the beginning of the incubation process for some of the samples.

### Sample analysis post-incubation

Ultraviolet–visible spectra were collected against a MilliQ water background, over a wavelength domain of 300–800 nm. The peak positions of the resulting spectra were assessed using the Savitzky–Golay method to derive the spectral plots in the SpecManager software (ACD Labs). After incubation, free proteins were eliminated by centrifugation of particles in a Heraeus Multifuge X1R table top centrifuge (Thermo Scientific) and removal of the supernatant. The silver ions in the supernatants were quantified through F-AAS. Ag NPs were washed with MilliQ water three times through re-dispersion of the pellets and TEM/STEM samples were prepared by dropping 5–10 μl of suspension on a formvar/carbon-supported copper grid (Ted Pella) and leaving it to dry overnight. Imaging and diffraction studies were performed using a Phillips CM20 transmission electron microscope working at 200 keV. EDS and X-ray elemental mapping experiments were performed on a Talos 200X STEM instrument.

### EDS and elemental mapping of supernatants

Silver nanocubes were incubated (10 μg ml−1) for 7 days in RPMI-1640 cell culture medium supplemented with 1% FBS. The resulting sample was centrifuged to pellet the particles. A drop of the supernatant was deposited on a formvar/carbon-supported TEM copper grid and left to dry overnight. 150 μl of the remaining supernatant was separated from the pelleted particles, moved to a clean Eppendorf tube and spiked with 40 μl of PVP-coated NanoXact 5 nm Ag NPs (nanoComposixm, stock concentration 20 μg ml−1). The NanoXact Ag NPs used for spiking are comparable in size to the observed Ag2S nanocrystals and the amount added provides a mass of silver comparable to that in the Ag2S nanocrystals formed at the Ag NPs. A drop of the spiked supernatant was deposited on a TEM grid and left to dry overnight. EDS spectra and elemental maps from the resulting samples were collected using a Talos 200X STEM machine.

### Cell line

The J774A.1 murine macrophage cell line (referred to as J774) was obtained from Cell Line Service (#400220). The cells were cultured in RPMI-1640 cell culture medium supplemented with penicillin (100 μg ml−1), streptomycin (100 U ml−1), GlutaMAX (1 ×) and 10% heat-inactivated FBS. The cells were kept in at 37 °C humidified atmosphere with 5% CO2. The cell culture medium and all the supplements were purchased from Gibco.

### Particle pre-incubation and toxicity studies

Pristine Ag nanocubes, as well as partially and completely sulphidated Ag nanocubes were used for toxicity testing. Silver NPs (2 μg ml−1) were pre-incubated in RPMI-1640 supplemented with 10 or 1% FBS, resulting in either their partial or their complete transformation into Ag2S (Supplementary Fig. 27). After pre-incubation, the samples were centrifuged, the supernatants were removed and the pelleted particles were re-suspended in RPMI-1640 with 10% FBS. Re-suspension was done in such a way as to up-concentrate the samples to the desired concentrations, namely 2, 5, 10, 15, 25, 50 and 100 μg ml−1 silver. For each of the final concentrations, pre-incubation was done in separate tubes. For the partially and completely transformed Ag NPs, up-concentration was done correcting for the amount of silver lost through ion release during pre-incubation. The resulting samples were fed to the J774 cells. Dosing of the cells was performed in a blinded experimental setting with the researcher performing the toxicity studies not being informed of the specific content of each tube provided for cell treatment. Cytokine production was quantified using a multiplex assay and cell mitochondrial activity was measured using an MTT assay (Supplementary Methods) in six separate replicates. Sample sizes down to three are routinely used in MTT assays. We believe larger sample numbers (six in this case) only serve to strengthen the significance of the results. Values are calculated as mean±standard deviation.

### Data availability

The authors declare that the data supporting the findings of this study are available within the article and its supplementary information files.

## Additional information

How to cite this article: Miclăuş, T. et al. Dynamic protein coronas revealed as a modulator of silver nanoparticle sulphidation in vitro. Nat. Commun. 7:11770 doi: 10.1038/ncomms11770 (2016).

## References

1. 1

   Monopoli, M. P., Åberg, C., Salvati, A. & Dawson, K. A. Biomolecular coronas provide the biological identity of nanosized materials. Nat. Nanotechnol 7, 779–786 (2012).

   CAS ADS Article Google Scholar

2. 2

   Walczyk, D., Baldelli Bombelli, F., Monopoli, M. P., Lynch, I. & Dawson, K. A. What the cell “sees” in bionanoscience. J. Am. Chem. Soc. 132, 5761–5768 (2010).

   CAS Article Google Scholar

3. 3

   Tenzer, S. et al. Rapid formation of plasma protein corona critically affects nanoparticle pathophysiology. Nat. Nanotechnol 8, 772–781 (2013).

   CAS ADS Article Google Scholar

4. 4

   Walkey, C. D. et al. Protein corona fingerprinting predicts the cellular interaction of gold and silver nanoparticles. ACS Nano 8, 2439–2455 (2014).

   CAS Article Google Scholar

5. 5

   Albanese, A. et al. Secreted biomolecules alter the biological identity and cellular interactions of nanoparticles. ACS Nano 8, 5515–5526 (2014).

   CAS Article Google Scholar

6. 6

   Walkey, C. D., Olsen, J. B., Guo, H., Emili, A. & Chan, W. C. W. Nanoparticle size and surface chemistry determine serum protein adsorption and macrophage uptake. J. Am. Chem. Soc. 134, 2139–2147 (2012).

   CAS Article Google Scholar

7. 7

   Pelaz, B. et al. Interfacing engineered nanoparticles with biological systems: anticipating adverse nano-bio interactions. Small 9, 1573–1584 (2013).

   CAS Article Google Scholar

8. 8

   Docter, D. et al. The nanoparticles biomolecule corona: lessons learned – challenge accepted? Chem. Soc. Rev. 44, 6094–6121 (2015).

   CAS Article Google Scholar

9. 9

   Del Pino, P. et al. Protein corona formation around nanoparticles – from the past to the future. Mater. Horiz 1, 301–313 (2014).

   CAS Article Google Scholar

10. 10

    Casals, E., Pfaller, T., Duschl, A., Oostingh, G. J. & Puntes, V. Time evolution of the nanoparticle protein corona. ACS Nano 4, 3623–3632 (2010).

    CAS Article Google Scholar

11. 11

    Röcker, C., Pötzl, M., Zhang, F., Parak, W. J. & Nienhaus, G. U. A quantitative fluorescence study of protein monolayer formation on colloidal nanoparticles. Nat. Nanotechnol 4, 577–580 (2009).

    ADS Article Google Scholar

12. 12

    Milani, S., Baldelli Bombelli, F., Pitek, A. S., Dawson, K. A. & Rädler, J. Reversible versus irreversible binding of transferrin to polystyrene nanoparticles: soft and hard corona. ACS Nano 6, 2533–2541 (2012).

    Article Google Scholar

13. 13

    Monopoli, M. P. et al. Physical-chemical aspects of protein corona: relevance to in vitro and in vivo biological impacts of nanomaterials. J. Am. Chem. Soc. 133, 2525–2534 (2011).

    CAS Article Google Scholar

14. 14

    Fedeli, C. et al. The functional dissection of the plasma corona of SiO2-NPs spots histidine rich glycoprotein as a major player able to hamper nanoparticle capture by macrophages. Nanoscale 7, 17710–17728 (2015).

    CAS ADS Article Google Scholar

15. 15

    Lundqvist, M. et al. Nanoparticle size and surface properties determine the protein corona with possible implications for biological impacts. Proc. Natl Acad. Sci. USA 105, 14265–14270 (2008).

    CAS ADS Article Google Scholar

16. 16

    Eigenheer, R. et al. Silver nanoparticle protein corona composition compared across engineered particle properties and environmentally relevant reaction conditions. Environ. Sci. Nano 1, 238–247 (2014).

    CAS Article Google Scholar

17. 17

    Nel, A. E. et al. Understanding the biophysicochemical interactions at the nano-bio interface. Nat. Mater. 8, 543–557 (2009).

    CAS ADS Article Google Scholar

18. 18

    Tenzer, S. et al. Nanoparticle size is a critical physic-chemical determinant of the human blood plasma corona: a comprehensive quantitative proteomic analysis. ACS Nano 5, 7155–7167 (2011).

    CAS Article Google Scholar

19. 19

    Deng, Z. J. et al. Differential plasma protein binding to metal oxide nanoparticles. Nanotechnology 20, 455101–455109 (2009).

    ADS Article Google Scholar

20. 20

    Walkey, C. D. & Chan, W. C. W. Understanding and controlling the interaction of nanomaterials with proteins in physiological environment. Chem. Soc. Rev. 41, 2780–2799 (2012).

    CAS Article Google Scholar

21. 21

    Lesniak, A. et al. Effects of the presence or absence of a protein corona on silica nanoparticle uptake and impact on cells. ACS Nano 6, 5845–5857 (2012).

    CAS Article Google Scholar

22. 22

    Liu, R., Jiang, W., Walkey, C. D., Chan, W. C. W. & Cohen, Y. Prediction of nanoparticles-cell association based on corona proteins and physicochemical properties. Nanoscale 7, 9664–9675 (2015).

    CAS ADS Article Google Scholar

23. 23

    Setyawati, M. I., Tay, C. Y., Docter, D., Stauber, R. H. & Leond, D. T. Understanding and exploiting nanoparticles’ intimacy with the blood vessel and blood. Chem. Soc. Rev. 44, 8174–8199 (2015).

    CAS Article Google Scholar

24. 24

    Miclăuş, T., Bochenkov, V. E., Ogaki, R., Howard, K. A. & Sutherland, D. S. Spatial mapping and quantification of soft and hard protein coronas at silver nanocubes. Nano Lett. 14, 2086–2093 (2014).

    ADS Article Google Scholar

25. 25

    Beer, C., Foldbjerg, R., Hayashi, Y., Sutherland, D. S. & Autrup, H. Toxicity of silver nanoparticles – nanoparticle or silver ion? Toxicol. Lett. 208, 286–292 (2012).

    CAS Article Google Scholar

26. 26

    Foldbjerg, R. et al. Silver nanoparticles – wolves in sheep’s clothing? Toxicol. Res 4, 563–575 (2015).

    CAS Article Google Scholar

27. 27

    Gliga, A. R., Skoglund, S., Wallinder, I. O., Fadeel, B. & Karlsson, H. L. Size-dependent cytotoxicity of silver nanoparticles in human lung cells: the role of cellular uptake, agglomeration and Ag release. Part. Fibre. Toxicol 11, 11–27 (2014).

    Article Google Scholar

28. 28

    Johnston, H. J. et al. A review of the in vivo and in vitro toxicity of silver and gold particulates: particle attributes and biological mechanism responsible for the observed toxicity. Crit. Rev. Toxicol. 40, 328–346 (2010).

    CAS Article Google Scholar

29. 29

    Henglein, A. Colloidal silver nanoparticles: photochemical preparation and interaction with O2, CCl4, and some metal ions. Chem. Mater. 10, 444–450 (1998).

    CAS Article Google Scholar

30. 30

    Lok, C.-N. et al. Silver nanoparticles: partial oxidation and antibacterial activities. J. Biol. Inorg. Chem. 12, 527–534 (2007).

    CAS Article Google Scholar

31. 31

    Sotiriou, G. A., Meyer, A., Knijnenburg, J. T. N., Panke, S. & Pratsinis, S. E. Quantifying the origin of released Ag+ ions from nanosilver. Langmuir 28, 15929–15936 (2012).

    CAS Article Google Scholar

32. 32

    Liu, J. & Hurt, R. H. Ion release kinetics and particle persistence in aqueous nano-silver colloids. Environ. Sci. Technol. 44, 2169–2175 (2010).

    CAS ADS Article Google Scholar

33. 33

    Ma, R. et al. Size-controlled dissolution of organic-coated silver nanoparticles. Environ. Sci. Technol. 46, 752–759 (2012).

    CAS ADS Article Google Scholar

34. 34

    Liu, J., Pennell, K. G. & Hurt, R. H. Kinetics and mechanism of nanosilver oxysulfidation. Environ. Sci. Technol. 45, 7345–7353 (2011).

    CAS ADS Article Google Scholar

35. 35

    Reinsch, B. C. et al. Sulfidation of silver nanoparticles decreases Escherichia coli growth inhibition. Environ. Sci. Technol. 46, 6992–7000 (2012).

    CAS ADS Article Google Scholar

36. 36

    Levard, C. et al. Sulfidation of silver nanoparticles: natural antidote to their toxicity. Environ. Sci. Technol. 47, 13440–13448 (2013).

    CAS ADS Article Google Scholar

37. 37

    Devi, G. P. et al. Sulfidation of silver nanoparticles reduces its toxicity in zebrafish. Aquat. Toxicol. 158, 149–156 (2015).

    CAS Article Google Scholar

38. 38

    Starnes, D. L. et al. Impact of sulfidation on the bioavailability and toxicity of silver nanoparticles to Caenorhabditis elegans. Environ. Pollut. 196, 239–246 (2015).

    CAS Article Google Scholar

39. 39

    Kim, B., Park, C.-S., Murayama, S. & Hochella, M. F. Jr. Discovery and characterization of silver sulfide nanoparticles in final sewage sludge products. Environ. Sci. Technol. 44, 7509–7514 (2010).

    CAS ADS Article Google Scholar

40. 40

    Kent, R. D., Oser, J. G. & Vikesland, P. J. Controlled evaluation of silver nanoparticle sulfidation in full-scale wastewater treatment plant. Environ. Sci. Technol. 48, 8564–8572 (2014).

    CAS ADS Article Google Scholar

41. 41

    Thalmann, B., Voegelin, A., Sinnet, B., Morgenroth, E. & Kaegi, R. Sulfidation kinetics of silver nanoparticles reacted with metal sulfides. Environ. Sci. Technol. 48, 4885–4892 (2014).

    CAS ADS Article Google Scholar

42. 42

    Yu, S.-J., Yin, Y.-G., Chao, J.-B., Shen, M.-H. & Liu, J.-F. Highly dynamic PVP-coated silver nanoparticles in aquatic environments: chemical and morphology change induced by oxidation of Ag0 and reduction of Ag+. Environ. Sci. Technol. 48, 403–411 (2014).

    CAS ADS Article Google Scholar

43. 43

    Liu, J., Sonshine, D. A., Shervani, S. & Hurt, R. H. Controlled release of biologically active silver from nanosilver surfaces. ACS Nano 4, 6903–6913 (2010).

    CAS Article Google Scholar

44. 44

    Gondikas, A. P. et al. Cysteine-induced modifications of zero-valent silver nanomaterials: implications for particles surface chemistry, aggregation, dissolution, and silver speciation. Environ. Sci. Technol. 46, 7037–7045 (2012).

    CAS ADS Article Google Scholar

45. 45

    Jiang, X. et al. Fast intracellular dissolution and persistent cellular uptake of silver nanoparticles in CHO-K1 cells: implication for cytotoxicity. Nanotoxicology 9, 181–189 (2015).

    CAS Article Google Scholar

46. 46

    Wang, L. et al. Use of synchrotron radiation-analytical techniques to reveal chemical origin of silver-nanoparticle cytotoxicity. ACS Nano 9, 6532–6547 (2015).

    CAS Article Google Scholar

47. 47

    Chen, S. et al. Sulfidation of silver nanowires inside human alveolar epithelial cells: a potential detoxification mechanism. Nanoscale 5, 9839–9847 (2013).

    CAS ADS Article Google Scholar

48. 48

    Chen, S. et al. High-resolution analytical electron microscopy reveals cell culture media-induced changes to the chemistry of silver nanowires. Environ. Sci. Technol. 47, 13813–13821 (2013).

    CAS ADS Article Google Scholar

49. 49

    Choi, O. et al. Role of sulfide and ligand strength in controlling nanosilver toxicity. Water. Res 43, 1879–1886 (2009).

    CAS Article Google Scholar

50. 50

    Bianchini, A. et al. Evaluation of the effect of reactive sulfide on the acute toxicity of silver (I) to Daphnia magna. Part 2: toxicity results. Environ. Toxicol. Chem. 21, 1294–1300 (2002).

    CAS Article Google Scholar

51. 51

    Mann, R. M., Ernste, M. J., Bell, R. A., Kramer, J. R. & Wood, C. M. Evaluation of the protective effects of reactive sulfide on the acute toxicity of silver to rainbow trout (Oncorhynchus Mykiss). Enviro. Toxicol. Chem 23, 1204–1210 (2004).

    CAS Article Google Scholar

52. 52

    Selected Powder Diffraction Data for Metals & Alloys Data Book. 1st edn. vol. 1, JCPDS International Center for Diffraction Data (1982).

53. 53

    Cia, X., Zeng, J., Zhang, Q., Moran, C. H. & Xia, Y. Recent developments in shape-controlled synthesis of silver nanocrystals. J. Phys. Chem. C 116, 21647–21656 (2012).

    Article Google Scholar

54. 54

    Wang, Y., Zheng, Y., Huang, C. Z. & Xia, Y. Synthesis of Ag nanocubes 18-32 nm in edge length: the effects of polyol on reduction kinetics, size control and reproducibility. J. Am. Chem. Soc. 135, 1941–1951 (2013).

    CAS Article Google Scholar

55. 55

    Elechiguerra, J. L. et al. Corrosion at the nanoscale: the case of silver nanowires and nanoparticles. Chem. Mater. 17, 6042–6052 (2005).

    CAS Article Google Scholar

56. 56

    El-Khairy, L., Ueland, P. M., Refsum, H., Graham, I. M. & Vollset, S. E. Plasma total cysteine as a risk factor for vascular disease. Circulation 103, 2544–2549 (2001).

    CAS Article Google Scholar

57. 57

    Salemi, G. et al. Blood levels of homocysteine, cysteine, glutathione, folic acid, and vitamin B12 in the acute phase of atherothrombosis stroke. Neural. Sci 30, 361–364 (2009).

    Article Google Scholar

58. 58

    Levard, C., Hotze, E. M., Lowry, G. V. & Brown, G. E. Jr. Environmental transformations of silver nanoparticles: Impact on stability and toxicity. Environ. Sci. Technol. 46, 6900–6914 (2012).

    CAS ADS Article Google Scholar

59. 59

    Bopst, M., Haas, C., Car, B. & Engster, H. P. The combined inactivation of tumor necrosis factor and interleukin-6 prevents induction of the major acute phase proteins by endotoxin. Eur. J. Immunol. 28, 4130–4137 (1998).

    CAS Article Google Scholar

60. 60

    Martinez-Gutierrez, F. et al. Antibacterial activity, inflammatory response, coagulation and cytotoxicity effects of silver nanoparticles. Nanomed. Nanotechnol 8, 328–336 (2012).

    CAS Article Google Scholar

61. 61

    Park, M.V.D.Z. et al. The effect of particle size on the cytotoxicity, inflammation, developmental toxicity and genotoxicity of silver nanoparticles. Biomaterials 32, 9810–9817 (2011).

    CAS Article Google Scholar

62. 62

    Driscoll, K. E. TNFα and MIP-2 production: role in particle-induced inflammation and regulation by oxidative stress. Toxicol. Lett. 112-113, 177–184 (2000).

    CAS Article Google Scholar

63. 63

    Zhang, Q., Li, W., Wen, L.-P., Chen, J. & Xia, Y. Facile synthesis of Ag nanocubes of 30 to 70 nm in edge length with CF3COOAg as a precursor. Chem. Eur. J 16, 10234–10239 (2010).

    CAS Article Google Scholar

64. 64

    Wiley, B., Sun, Y., Mayers, B. & Xia, Y. Shape-controlled synthesis of metal nanoparticles: the case of silver. Chem. Eur. J 11, 454–463 (2005).

    CAS Article Google Scholar

65. 65

    Foldbjerg, R., Dang, D. A. & Autrup, H. Cytotoxicity and genotoxicity of silver nanoparticles in the human lung cancer cell line, A549. Arch. Toxicol. 85, 743–750 (2011).

    CAS Article Google Scholar

66. 66

    Reidy, B., Haase, A., Luch, A., Dawson, K. A. & Lynch, I. Mechanism of silver nanoparticle release, transformation and toxicity: a critical review of current knowledge and recommendations for future studies and applications. Materials 6, 2295–2350 (2013).

    CAS ADS Article Google Scholar

67. 67

    Helmlinger, J. et al. Silver nanoparticles with different size and shape: equal cytotoxicity, but different antibacterial effects. RSC Adv 6, 18490–18501 (2016).

    CAS Article Google Scholar

68. 68

    Foldbjerg, R. et al. Global gene expression profiling of human lung epithelial cells after exposure to nanosilver. Toxicol. Sci. 130, 145–157 (2012).

    CAS Article Google Scholar

69. 69

    Jiang, X. et al. Multi-platform genotoxicity analysis of silver nanoparticles in the model cell line CHO-K1. Toxicol. Lett. 222, 55–63 (2013).

    CAS Article Google Scholar

Download references

## Acknowledgements

This work was funded through a Danish strategic research council grant (SIDANA 09-067185). The research leading to these results has received funding from the European Community’s Seventh Framework Programme under grant agreement no 602699 (DIREKT). V.E.B. acknowledges the support from RFBR grant 15-03-99582. We thank Mauro Porcu from FEI for his help with the preliminary STEM study.

## Author information

### Affiliations

1. Interdisciplinary Nanoscience Center (iNANO), Aarhus University, Gustav Wieds Vej 14, Aarhus, 8000, Denmark

   Teodora Miclăuş, Vladimir E. Bochenkov & Duncan S. Sutherland

2. Department of Public Health, Aarhus University, Bartholins Alle 2, Aarhus, 8000, Denmark

   Christiane Beer

3. Department of Physics, Aarhus University, Ny Munkegade 120, Aarhus, 8000, Denmark

   Jacques Chevallier

4. Department of Molecular Biology and Genetics, Aarhus University, Gustav Wieds Vej 10, Aarhus, 8000, Denmark

   Carsten Scavenius & Jan J. Enghild

5. Department of Chemistry, Lomonosov Moscow State University, Leninskie gory 1/3, Moscow, 119991, Russia

   Vladimir E. Bochenkov

Authors

1. Teodora Miclăuş
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Christiane Beer
   View author publications

   You can also search for this author in PubMed Google Scholar

3. Jacques Chevallier
   View author publications

   You can also search for this author in PubMed Google Scholar

4. Carsten Scavenius
   View author publications

   You can also search for this author in PubMed Google Scholar

5. Vladimir E. Bochenkov
   View author publications

   You can also search for this author in PubMed Google Scholar

6. Jan J. Enghild
   View author publications

   You can also search for this author in PubMed Google Scholar

7. Duncan S. Sutherland
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

T.M. and D.S.S. designed the experiments, except for the cell studies. T.M., C.B. and D.S.S. designed the toxicology experiments and C.B. performed them. T.M. performed all other experiments except FDTD simulations (V.E.B.), mass spectrometry (C.S. and J.E.) and EDS, elemental mapping and TEM diffraction (T.M and J.C). T.M and D.S.S. analysed the data, except for EDS and diffraction (T.M., J.C. and D.S.S), mass spectrometry (T.M., C.S. and J.E.), toxicology (T.M., C.B. and D.S.S.) and simulations data (T.M, V.E.B.). T.M and D.S.S. wrote the manuscript and the Supplementary Information.

### Corresponding author

Correspondence to Duncan S. Sutherland.

## Ethics declarations

### Competing interests

The authors declare no competing financial interests.

## Supplementary information

Supplementary Figures 1-29, Supplementary Tables 1-7, Supplementary Discussion, Supplementary Methods and Supplementary References (PDF 5087 kb)

## Rights and permissions

This work is licensed under a Creative Commons Attribution 4.0 International License. The images or other third party material in this article are included in the article’s Creative Commons license, unless indicated otherwise in the credit line; if the material is not included under the Creative Commons license, users will need to obtain permission from the license holder to reproduce the material. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/

Reprints and Permissions

## About this article

### Cite this article

Miclăuş, T., Beer, C., Chevallier, J. et al. Dynamic protein coronas revealed as a modulator of silver nanoparticle sulphidation in vitro. Nat Commun 7, 11770 (2016). https://doi.org/10.1038/ncomms11770

Download citation

- Received: 25 February 2016

- Accepted: 28 April 2016

- Published: 09 June 2016

- DOI: https://doi.org/10.1038/ncomms11770

### Share this article

Anyone you share the following link with will be able to read this content:

Sorry, a shareable link is not currently available for this article.

Provided by the Springer Nature SharedIt content-sharing initiative

## Further reading

- ### The mechanism of cell death induced by silver nanoparticles is distinct from silver cations

  - Monica M. Rohde
  - Christina M. Snyder
  - Ravi Singh

  Particle and Fibre Toxicology (2021)

- ### Particle number-based trophic transfer of gold nanomaterials in an aquatic food chain

  - Fazel Abdolahpur Monikh
  - Latifeh Chupani
  - Willie J.G.M. Peijnenburg

  Nature Communications (2021)

- ### Evidence of a non-apoptotic mode of cell death in microglial BV-2 cells exposed to different concentrations of zinc oxide nanoparticles

  - Sudhakaran Sruthi
  - Thomas Nury
  - Gérard Lizard

  Environmental Science and Pollution Research (2021)

- ### Particle toxicology and health - where are we?

  - Michael Riediker
  - Daniele Zink
  - Flemming Cassee

  Particle and Fibre Toxicology (2019)

- ### Determining surface chemical composition of silver nanoparticles during sulfidation by monitoring the ligand shell

  - John M. Pettibone
  - Justin M. Gorham
  - Jingyu Liu

  Journal of Nanoparticle Research (2018)

## Comments

By submitting a comment you agree to abide by our Terms and Community Guidelines. If you find something abusive or that does not comply with our terms or guidelines please flag it as inappropriate.

Download PDF

Advertisement

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing